@@ -293,7 +293,7 @@ locate_gir (GIrParser  *parser,
   return NULL;
 }
 
-#define MISSING_ATTRIBUTE(ctx,error,element,attribute)			        \
+#define MISSING_ATTRIBUTE(context,error,element,attribute)			        \
   do {                                                                          \
     int line_number, char_number;                                                \
     g_markup_parse_context_get_position (context, &line_number, &char_number);  \
@@ -1480,6 +1480,7 @@ start_member (GMarkupParseContext *context,
   const gchar *name;
   const gchar *value;
   const gchar *deprecated;
+  const gchar *c_identifier;
   GIrNodeEnum *enum_;
   GIrNodeValue *value_;
 
@@ -1490,6 +1491,7 @@ start_member (GMarkupParseContext *context,
   name = find_attribute ("name", attribute_names, attribute_values);
   value = find_attribute ("value", attribute_names, attribute_values);
   deprecated = find_attribute ("deprecated", attribute_names, attribute_values);
+  c_identifier = find_attribute ("c:identifier", attribute_names, attribute_values);
 
   if (name == NULL)
     {
@@ -1509,6 +1511,10 @@ start_member (GMarkupParseContext *context,
   else
     value_->deprecated = FALSE;
 
+  g_hash_table_insert (((GIrNode *)value_)->attributes,
+                       g_strdup ("c:identifier"),
+                       g_strdup (c_identifier));
+
   enum_ = (GIrNodeEnum *)CURRENT_NODE (ctx);
   enum_->values = g_list_append (enum_->values, value_);
 
